// Manejo del cobro
let total = 0;
const productosVendidos = {}; // Objeto para almacenar las cantidades vendidas por producto

// Función para enviar la venta al servidor
function enviarVenta(nombreProducto, cantidad, precioTotal) {
    const fechaVenta = new Date().toISOString().split('T')[0];
    const horaVenta = new Date().toLocaleTimeString(); // Obtiene la hora local

    const ventaData = {
        producto: nombreProducto,
        cantidad: cantidad,
        total: precioTotal,
        fecha: fechaVenta,
        hora: horaVenta
    };

    try {
        const ventaDataJSON = JSON.stringify(ventaData);
        console.log('Datos que se enviarán:', ventaDataJSON);

        fetch('registrar_venta.php', {
            method: 'POST',
            headers: { 'Content-Type': 'application/json' },
            body: ventaDataJSON
        })
            .then(response => response.json())
            .then(data => {
                console.log('Respuesta del servidor:', data);
            })
            .catch(error => {
                console.error('Error al registrar la venta:', error);
            });
    } catch (error) {
        console.error('Error al formatear el JSON:', error);
    }
}

// Selección de tarjetas de producto
const productCards = document.querySelectorAll('.product-card');

productCards.forEach(card => {
    card.addEventListener('click', function () {
        const price = parseFloat(card.getAttribute('data-price'));
        const productName = card.querySelector('h5').textContent;

        if (productosVendidos[productName]) {
            productosVendidos[productName].cantidad += 1;
        } else {
            productosVendidos[productName] = { cantidad: 1, precio: price };
        }

        total += price;
        document.getElementById('total-price').textContent = `$${total.toFixed(2)}`;
    });
});

// Función para registrar la venta al presionar el botón "Registrar"
document.getElementById('reset-btn').addEventListener('click', function () {
    for (let producto in productosVendidos) {
        const { cantidad, precio } = productosVendidos[producto];
        enviarVenta(producto, cantidad, cantidad * precio);
    }
    
    // Reiniciar total después de registrar
    total = 0;
    document.getElementById('total-price').textContent = `$${total.toFixed(2)}`; 
    for (let producto in productosVendidos) {
        productosVendidos[producto].cantidad = 0;
    }
});

// Función para limpiar el total sin registrar la venta
document.getElementById('clear-total-btn').addEventListener('click', function () {
    total = 0;
    document.getElementById('total-price').textContent = `$${total.toFixed(2)}`;
    for (let producto in productosVendidos) {
        productosVendidos[producto].cantidad = 0;
    }
});


// JavaScript para la contraseña
document.getElementById('logo-link').addEventListener('click', function (event) {
    event.preventDefault(); // Evitar la acción predeterminada del enlace
    var password = prompt('Introduce la contraseña:');
    if (password === 'Nom@nche$.') {
        window.location.href = 'estadistica.html'; // Redirige a cobro.html si la contraseña es correcta
    } else {
        alert('Contraseña incorrecta');
    }
});

// se aplique la animación
document.querySelectorAll('.button').forEach(button => {
    button.addEventListener('click', () => {
        button.classList.add('clicked');
        setTimeout(() => {
            button.classList.remove('clicked');
        }, 600); // Duración de la animación en milisegundos
    });
});

// Función luz menú
document.querySelector('.navbar-toggler').addEventListener('click', function () {
    this.classList.toggle('iluminado'); // Alterna la clase 'iluminado' cuando se presiona el botón
});
